# How to contribute

We'd love to accept your patches and contributions to this project.
There are just a few small guidelines you need to follow.

- Unless you explicitly state otherwise, any contribution intentionally
  submitted for inclusion in work by you shall be dual licensed under MIT
  license or Apache-2.0 license without any additional terms or conditions.
- All submissions, including submissions by project members, require review.
  We use GitHub pull requests for this purpose.
  Consult GitHub Help for more information on using pull requests.
